#
# spec file for package gnome-bluetooth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _udevdir %(pkg-config --variable udevdir udev)
Name:           gnome-bluetooth
Version:        46.0
Release:        1.2
Summary:        GNOME Bluetooth graphical utilities
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/GnomeBluetooth
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.44
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gsound)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4
BuildRequires:  pkgconfig(libnotify) >= 0.7.0
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(upower-glib) >= 0.99.14
# Require bluez (mandatory, as per readme, bnc#622946)
Requires:       bluez >= 5
# ensure BT is enabled at startup (glgo#GNOME/gnome-bluetooth#110)
Recommends:     bluez-auto-enable-devices

%description
A set of graphical utilities to setup, monitor and use Bluetooth devices.

This package provides the utilities, data files and manuals for GNOME Bluetooth.

%package -n libgnome-bluetooth-3_0-13
Summary:        GNOME Bluetooth's Shared Libraries
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgnome-bluetooth-3_0-13
A set of graphical utilities to setup, monitor and use Bluetooth devices.

This package provides the GNOME Bluetooth's shared library.

%package -n libgnome-bluetooth-ui-3_0-13
Summary:        GNOME Bluetooth's Shared Libraries
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libgnome-bluetooth-ui-3_0-13
A set of graphical utilities to setup, monitor and use Bluetooth devices.

This package provides the GNOME Bluetooth's shared library.

%package -n typelib-1_0-GnomeBluetooth-3_0
Summary:        Introspection bindings for the GNOME Bluetooth libraries
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-GnomeBluetooth-3_0
A set of graphical utilities to setup, monitor and use Bluetooth devices.

This package provides the GObject Introspection bindings for the GNOME Bluetooth's
libraries.

%package devel
Summary:        Development files for the GNOME Bluetooth libraries
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
Requires:       libgnome-bluetooth-3_0-13 = %{version}
Requires:       libgnome-bluetooth-ui-3_0-13 = %{version}
Requires:       typelib-1_0-GnomeBluetooth-3_0 = %{version}

%description devel
A set of graphical utilities to setup, monitor and use Bluetooth devices.

This package provides the necessary files for development with GNOME Bluetooth.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D gtk_doc=true \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}-3.0 %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}

%ldconfig_scriptlets -n libgnome-bluetooth-3_0-13
%ldconfig_scriptlets -n libgnome-bluetooth-ui-3_0-13

%files
%license COPYING
%doc NEWS README.md
%{_bindir}/bluetooth-*
%{_datadir}/applications/bluetooth-sendto.desktop
%dir %{_datadir}/gnome-bluetooth-3.0
%{_datadir}/gnome-bluetooth-3.0/pin-code-database.xml
%{_mandir}/man1/bluetooth-*

%files -n libgnome-bluetooth-3_0-13
%license COPYING.LIB
%{_libdir}/libgnome-bluetooth-3.0.so.*

%files -n libgnome-bluetooth-ui-3_0-13
%license COPYING.LIB
%{_libdir}/libgnome-bluetooth-ui-3.0.so.*

%files -n typelib-1_0-GnomeBluetooth-3_0
%{_libdir}/girepository-1.0/GnomeBluetooth-3.0.typelib

%files devel
%doc AUTHORS ChangeLog.README MAINTAINERS
%doc %{_datadir}/gtk-doc/html/gnome-bluetooth-3.0
%{_includedir}/gnome-bluetooth-3.0
%{_libdir}/libgnome-bluetooth-3.0.so
%{_libdir}/libgnome-bluetooth-ui-3.0.so
%{_libdir}/pkgconfig/gnome-bluetooth-3.0.pc
%{_libdir}/pkgconfig/gnome-bluetooth-ui-3.0.pc
%{_datadir}/gir-1.0/*.gir

%files lang -f %{name}-3.0.lang

%changelog
* Mon Mar 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + This version modernises the look of the properties dialogue.
* Mon Feb  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.8:
  + This update fixes problems with some devices not disappearing
    from the list of quick settings in GNOME Shell.
* Thu Nov 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.7:
  + Fix bugs that stopped the Obex Push server from automatically
    accepting files from paired devices.
  + Fix bugs that caused the device's Connection switch to appear
    out of sync with the connection state.
  + Build fixes.
  + Updated translations.
* Mon Aug 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.6:
  + Fix problems with icons for mice and tablets.
  + Updates status labels to be dimmed by default.
  + Updated translations.
* Tue Dec 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.5:
  + This version fixes the pairing dialogue misbehaving for some
    Bluetooth Classic keyboards, with the passkey disappearing
    after the first digit is typed.
- Add missing ldconfig_scriptlets macro for
  libgnome-bluetooth-ui-3_0-13.
* Tue Sep  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.4:
  + This version switches the power state API added in version 42.3
    to be backed by the experimental PowerState property in
    bluetoothd. The API will not show transitional states if the
    version of bluetoothd is too old.
  + The battery API now exports the battery information for all
    Bluetooth devices listed in UPower, not just the ones
    re-exported from bluetoothd.
* Wed Aug 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.3:
  + This version adds a new API for more precise adapter power
    state, and fixes a number of small UI problems in
    bluetooth-sendto.
* Thu Jul  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + This version fixes duplicate devices appearing when bluetoothd
    restarts, as well as the discovery not being updated correctly
    in that same situation.
* Thu Jun  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.1:
  + Fix the display of devices with '&' in their names.
  + Updated translations.
* Tue Apr 12 2022 Frederic Crozat <fcrozat@suse.com>
- Recommends bluez-auto-enable-devices to ensure BT is enabled
  at startup (glgo#GNOME/gnome-bluetooth#110).
* Fri Mar 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Updated translations.
* Thu Mar 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + This version of gnome-bluetooth fixes a problem that could lead
    to gnome-shell's Bluetooth menu not appearing when it should
    have. This version also makes the Connect switch available for
    Bluetooth LE MIDI devices.
* Wed Feb 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta.2:
  + This version of gnome-bluetooth contains a number of bug fixes
    related to the GTK4 port, including spinners not spinning,
    device removal confirmation dialog not appearing, pairing
    dialog not disappearing, and a work-around to a UPower
    reference leak that could lead to a crash in the main
    libraries, as well as fixes for basic functionality in
    bluetooth-sendto.
* Tue Feb  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + This version of gnome-bluetooth adds a number of APIs to
    eventually be used in Settings and gnome-shell:
  - Export battery information for Bluetooth devices which
    support it.
  - Check whether any input devices are connected, so as to be
    able to show a confirmation dialogue when switching off
    Bluetooth.
  - Check whether a device can be connected to.
- Add pkgconfig(upower-glib) BuildRequires: New dependency.
* Thu Feb  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha.2:
  + This version of gnome-bluetooth splits the libraries into UI
    and non-UI versions. The UI library is only exposed as a native
    library for the benefit of gnome-control-center, and the non-UI
    library is only exposed as an introspected library for the
    benefit of gnome-shell.
- Package new libgnome-bluetooth-ui-3_0-13 sub-package.
- Drop 755fd758f866d3a3f7ca482942beee749f13a91e.patch: Fixed
  upstream.
* Thu Feb  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 755fd758f866d3a3f7ca482942beee749f13a91e.patch Fix build with
  meson 0.61 and newer.
* Fri Jan  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha:
  + Port library to GTK4
  + Remove chooser widgets from library
  + Remove chooser UI from bluetooth-sendto
  + Make bluetooth-sendto optional
  + Replace canberra-gtk dependency with gsound
  + GtkTreeModel-based API was replaced by a GListModel-based API
  + Loads of bug fixes, many new tests
  + Make changes to the way the default adapter is selected, see
    README.md for details.
- Following upstreams port:
  + Drop: pkgconfig(gtk+-3.0) and pkgconfig(libcanberra-gtk3)
    BuildRequires.
  + Add: pkgconfig(gtk4), pkgconfig(gsound) and
    pkgconfig(libadwaita-1) BuildRequires.
- Rename libgnome-bluetooth13 to libgnome-bluetooth-3_0-13,
  typelib-1_0-GnomeBluetooth-1_0 to typelib-1_0-GnomeBluetooth-3_0
  and gnome-bluetooth2-lang to gnome-bluetooth-3.0-lang following
  upstreams changes.
* Sat Nov  6 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add missing explicit libgnome-bluetooth13 Requires to devel sub
  package, it was already pulled in via typelib Requires, so no
  real world change.
- Use ldconfig_scriptlets macro for post(un) handling.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Wed Mar 24 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.34.5 (bsc#1186277):
  + Fix unwanted soname change.
- Changes from version 3.34.4:
  + Use device alias instead of device name in Settings UI, and
    don't show devices without a name.
  + Avoid new devices jumping around in the Settings list.
  + Fix a warning and a hang when opening the Bluetooth Settings.
  + Fix a possible hang when switching away from the Bluetooth
    Settings.
  + Make the "Cancel" button work when pairing keyboards.
  + Remove joypad quirks in favour of BlueZ autopair ones.
  + Remove a number of deprecated calls.
* Sun Oct  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.3:
  + Fix problem with intermittent connection work-around when using
    the switch in the device properties.
  + Updated translations.
* Wed Sep 23 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Work-around intermittent connection problems by disabling
    discovery when connecting to devices.
  + Hide pairing dialogue when pairing fails.
  + Allow $HOME to be the Downloads dir.
  + Better handling of the 8bitdo Zero gamepad.
  + Updated translations.
* Wed Mar 11 2020 mgorse@suse.com
- Update to version 3.34.1:
  + Prefer “Alias” adapter name to “Name”.
  + Fix some memory leaks.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Sep  6 2019 Michael Gorse <mgorse@suse.com>
- Update to version 3.34.0:
  + Fix possible use-after-free when using some gnome-shell
    extensions.
  + Updated translations.
* Mon Sep  2 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Describe "Reveal" as "Open Containing Folder".
  + Updated translations.
* Tue Mar 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Fix setup of devices that don't need pairing.
  + Always try to pair pointer devices.
  + Delegate audio devices quirks to bluez, which means that more
    PIN codes can be tried without user intervention.
  + Disable discovery when switching settings.
  + Fix possible warnings when switching settings.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Add quirk for Evoluent VerticalMouse 4.
* Sat Feb 16 2019 bjorn.lie@gmail.com
- Update to version 3.31.1:
  + Accessibility fixes and support for narrow displays in the
    Settings panel widget.
  + Add support for another "Microsoft Sculpt Comfort Mouse".
  + Build improvements.
- Drop gnome-bluetooth-Add-Sculpt-Comfort-Mouse.patch: Fixed
  upstream.
* Sun Dec 30 2018 bjorn.lie@gmail.com
- Add gnome-bluetooth-Add-Sculpt-Comfort-Mouse.patch: lib: Add
  another oui for "Microsoft Sculpt Comfort Mouse".
* Wed Aug  1 2018 bjorn.lie@gmail.com
- Update to version 3.28.2:
  + Use feature of BlueZ 5.51 to avoid Bluetooth adapters being
    left discoverable if the Settings panel exits suddenly.
  + Build warning fixes.
- Add pkgconfig(gio-unix-2.0), pkgconfig(gmodule-2.0) and
  pkgconfig(libnotify) BuildRequires and drop pkgconfig(udev)
  BuildRequires, align with what meson checks for.
* Mon Jul 23 2018 dimstar@opensuse.org
- Help translation-update-upstream finding the right gettext domain
  name: pass "po gnome-bluetooth2" to the call.
* Thu Jul 19 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Work-around a race in bluetoothd which would leave Bluetooth
    adapters discoverable even after the Settings panel closed
    cleanly.
  + Fix icons in Persian and Punjabi translations.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Tue Mar 13 2018 jengelh@inai.de
- Update summaries.
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Avoid crash when Bluetooth panel is switched away from quickly.
  + Fix connection button state becoming out of sync after
    disconnect.
  + Make sure to remove all the devices when bluetoothd crashes.
  + Stop spinner when it becomes invisible.
  + Fix compile-time warning.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Thu Feb 15 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Simplify and make BluetoothClient more efficient.
  + Fix problems when Bluetooth adapters come and go.
  + Remove quirks already handled by autopair plugin.
- Update Url tag to https://wiki.gnome.org/Projects/GnomeBluetooth,
  current GNOME Bluetooth's web page.
- Rename enable-gtk-doc meson option to gtk_doc following upstream
  change.
- Add LGPL-2.1+ to the License tag for compliance with the
  libraries' copyrights.
- Update summaries and descriptions to express more accurately each
  subpackage's content.
- Drop update-desktop-files BuildRequires and its macro: it is no
  longer needed.
* Fri Sep 15 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Fix installation of Bluetooth icons.
  + Fix Bluetooth icon names for bluetooth-sendto in various
    translations.
* Mon Sep 11 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Fix "file received" notifications not being translated.
  + Updated translations.
* Fri Sep  8 2017 jengelh@inai.de
- Update package summaries. Avoid running fdupes across hardlink
  boundaries.
* Tue Aug 29 2017 dimstar@opensuse.org
- Update to version 3.25.91:
  + Port to meson build system, and remove autotools build system.
  + Use Unicode in translatable strings.
  + Update Settings UI for updated gnome-control-center UI.
  + Align the explanatory text with the listbox.
  + Fix crash when exiting panel during pairing.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Drop %%glib2_gsettings_schema_*, desktop_database_* and
  %%icon_theme_cache_* post/postun macros: the functionality is now
  covered by file triggers.
- Add gtk-doc BuildRequires: new dependency, as we no longer
  receive the docs pre-built in the tarball.
- Drop intltool BuildRequires: no longer needed.
* Mon Feb 13 2017 zaitor@opensuse.org
- Update to version 3.20.1:
  + Unknown device types now show as "Unknown" rather than "All
    types".
  + Fix an invisible spinner when pairing.
  + Fix PIN font size.
- Drop gnome-bluetooth-plugins-geoclue Obsoletes: Not been around
  since version 3.11.3, no current openSUSE release carry this.
- Drop libgnomebt-devel Obsoletes/Provides and libgnomebt1
  Provides: Not been around since 2009.
* Sat Oct  1 2016 zaitor@opensuse.org
- Drop obexd-client Requires: obex was merged into bluez a long
  time ago, and we already pull it.
- Drop no longer needed Provides/Obsoletes: bluez-gnome and
  nautilus-sendto-plugin-bluetooth.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Stop passing V=1 to make, we do debugging locally.
* Mon Jun 27 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Add support for joysticks.
  + Fix small memory leaks.
  + Fix a runtime warning when the vendor is unknown.
  + Fix PIN label size.
* Fri Apr 15 2016 hpj@suse.com
- Update to GNOME 3.20 -- Fate#318572.
- Remove 61-gnome-bluetooth-rfkill.rules (no longer needed).
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 3.18.3:
  + Trust devices paired from the remote device.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.18.2:
  + Added API to export adapter status.
  + Updated translations.
* Tue Nov 10 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fix a number of style regressions in PIN dialogues.
  + Updated translations.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Nothing in gnome-bluetooth now needs gnome-control-center so
  remove the recommendation as non-GNOME solutions based on
  gnome-bluetooth exist.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + This version of the library adds Obex support to the settings
    widget. When the settings panel will be opened, other devices
    will be able to send files to the computer.
  + Remove outdated end-user documentation.
  + Settings:
  - Better empty and disabled state views.
  - Handle service authorisation requests for HID devices (mice,
    joypads).
  - Fix phone icon if extra icons aren't installed.
  - Add default PIN for Logitech Ultrathin Touch mouse and
    Microsoft Sculpt Comfort mice.
  + Send-to:
  - Show better error message when sending a file fails.
  - Disallow sending files to iDevices, they don't support Obex.
- Add pkgconfig(libcanberra-gtk3) and pkgconfig(libnotify)
  BuildRequires: New dependencies.
* Sat Apr 18 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix Bluetooth 2.1 keyboards not being pairable.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Jan 20 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Fix some memory leaks in BluetoothAgent.
  + Deprecation warning fixes.
  + Use widget templates to create the UI.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Fix properties dialog bugs.
  + Fix incorrect use of "Setup" as an adjective.
  + Use header bar buttons in bluetooth-sendto.
* Thu May 22 2014 werner@suse.de
- Require the udev library for build to allow the move
  of udev.pc back to udev
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Fix crasher with GTK+ dialogue changes.
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Add missing libudev private requires.
  + Require GTK+ 3.11.2.
  + Fix crasher with latest GTK+.
  + Remove GtkStock usage.
  + Updated translations.
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Obsolete the separate wizard, instead a widget to create a
    Bluetooth Settings panel is provided and will be used by
    gnome-control-center.
  + Removed APIs:
  - settings/wizard plugins API.
  - killswitch (now handled by gnome-settings-daemon's Rfkill
    plugin).
  - applet gir library.
  + Better icons for headphones, headsets, Apple, Google and
    Samsung phones.
- No longer package 61-gnome-bluetooth-rfkill.rules: it lives now
  officially andf formally in gnome-settings-daemon.
- Drop gnome-bluetooth-plugins-geoclue subpackage and obsolete it
  from the main package: gnome-bluetooth no longer suppoers
  plugins.
- No longer pass --disable-scrollkeeper and
  - -enable-nautilus-sendto to configure: those parameters haven't
  been valid for a few releases.
- Rename libgnome-bluetooth12 subpackage to libgnome-bluetooth13,
  following upstreams soname change.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Fix the Bluetooth status icon not appearing in gnome-shell.
  + Fix crashes when the "Connect" switch is used.
  + Add pairing support for the Microsoft Wedge Touch Mouse.
* Wed Sep  4 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Wizard:
  - Remove extraneous tabs.
  + Fix some issues freeing memory.
  + Updated translations.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Fix possible assertion with newer kernels on some hardware.
  + Port to BlueZ 5.
  + API documentation fixes.
  + Send-To:
  - Fix "Retry" button.
  - Set the From label as soon as we create the window.
  - Clear the progress bar text when there's an error.
  - Remove duplicate header label.
  - Show when all the transfers have completed.
  + Wizard:
  - Fix buttons when "retry" is clicked.
  - Only enable "PIN options" button if device is selected.
  - Hide PIN options dialogue if the selected device changes.
- Rename libgnome-bluetooth11 subpackage to libgnome-bluetooth12,
  following upstreams soname change.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Fix introspection generation for Vala.
  + Updated translations.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Remove fallback applet as GNOME fallback is obsolete.
  + Remove ObexFTP browsing support.
  + Fix help links in GNOME 3.6+.
  + Sendto: Remove nautilus-sendto plugin.
- Drop and obsolete nautilus-sendto-plugin-bluetooth.
- Drop pkgconfig(libnotify) BuildRequires: no longer needed.
- Remove traces of BUILD_FROM_VCS.
* Tue Nov 27 2012 dimstar@opensuse.org
- Move udev rules.d files to the right location:
  + Add pkgconfig(udev) BuildRequires.
  + Define _udevdir based on udevdir variable in udev.pc
  + Fix install section to make use of _udevdir.
* Thu Nov 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Library:
  - Fix crasher using BlueZ's development version.
  - Fix Connect/Disconnect functions not working.
  - Add internal helper to talk to /dev/rfkill.
  + Wizard:
  - Add another OUI for Apple trackpad.
  - Fix crasher doing substring matching.
  - Add a white button press (meaning Return) for iCades.
* Wed Oct 10 2012 coolo@suse.com
- own udev directories to avoid udev buildrequire
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Fix warning in BluetoothAgent
  + Add pairing support for iCade variants (mobile, core and jr.)
  + Use yelp-tools instead of gnome-doc-utils
  + Support LXDE with the fallback applet too
  + Updated translations.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstream.
- Drop lxde-support.patch: fixed upstream.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Allow building with nautilus-sendto 3.6
  + Namespace killswitch API properly
  + Loads of API documentation fixes
* Wed Jul 18 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Library: Fix stuck "Finishing" page for some devices.
  + Applet: Fix warning and empty device name in some cases.
  + Wizard: Use shorter label for the finishing pages.
- Rename libgnome-bluetooth10 subpackage to libgnome-bluetooth11,
  following upstreams soname bump.
* Wed Jul  4 2012 dimstar@opensuse.org
- Update to version 3.4.2:
  + Library:
  - Support for BlueZ 5.0 API
  - Fix memory leak when registering the pairing agent
  + Applet:
  - Fix assertion in gnome-shell when a device requires
    authorisation
  + Wizard:
  - Fix Simple Pairing never succeeding
  - Fix stuck "Finishing page" for some devices
- Drop gnome-bluetooth-fix-pairing.patch and
  gnome-bluetooth-fix-stuck-finish-page.patch: fixed upstream.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Sat Jun 30 2012 badshah400@gmail.com
- Added gnome-bluetooth-fix-pairing.patch and
  gnome-bluetooth-fix-stuck-finish-page.patch to enable pairing of
  devices again (bnc#769536, bgo#679190, rh#819203).
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 3.4.1:
  + Library:
  - Fix potential crashes when registering pairing agents with no
    adapter present
  - Fix warning when bluetooth-sendto exits
  - Better API documentation
  - Fix warnings related to BluetoothStatusClass
  + Send-To:
  - Document the --name option
  - Make the "Retry" button always visible
  - Fix warnings when saving the last used address
  + Wizard:
  - Fix setup of devices that don't require pairing
  + Updated translations.
* Thu May 31 2012 glin@suse.com
- Update 61-gnome-bluetooth-rfkill.rules due to the removal of
  udev-acl in udev >= 182.
* Tue Mar 27 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Tue Mar 20 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Applet:
  - String fixes
  + Library:
  - Remove generated file from version control
  + Wizard:
  - Add support for pairing the iCade
  - Improve support for keyboard PINs
  - Add OUI for Apple Magic Trackpad
  - Add OUI for Sony BD Remote Control
* Wed Jan 18 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Applet:
  - Fix newly paired devices not appearing in menus
  - Update fallback menu to match GNOME Shell's
  + Library:
  - Make the Connect/Disconnect helper function work
  - Do not use dbus-glib-1 when building introspection data
  - Remove header from chooser widget, breaks API
  + Wizard:
  - Fix assertion when exiting
  - Remove "Device Setup Failed" label from the sidebar
  - A number of UI tweaks
  + Plus build fixes, and the removal of the unmaintained Moblin UI
- Drop gnome-bluetooth-no-dbus-glib.patch: fixed upstream.
- Rename libgnome-bluetooth9 subpackage to libgnome-bluetooth10,
  following upstream soversion change.
* Wed Jan 11 2012 vuntz@opensuse.org
- Change gnome-control-center Requires to Recommends, to avoid a
  build loop.
* Sat Dec 24 2011 gankov@opensuse.org
- Add gnome-control-center Requires for bluetooth setup to work
  (bnc#732689)
* Fri Dec 23 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Library:
  - GVariant fixes
  - Build improvements
  + Applet:
  - Fix a packing issue
  + Wizard:
  - Improvements in the handling of PIN codes
  - Fix a segfault
  - Fix an UI issue with the "Close" button
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Wed Dec 21 2011 vuntz@opensuse.org
- Remove gtk2-devel Requires from devel subpackage: it will
  automatically be added the pkgconfig() way.
- Rewrite summary and description of devel subpackage.
- Change group of libgnome-bluetooth9 and
  typelib-1_0-GnomeBluetooth-1_0 from System/GUI/GNOME to
  System/Libraries.
- Add gnome-bluetooth-no-dbus-glib.patch: finish removing dbus-glib
  usage in the build system.
- Remove pkgconfig(dbus-glib-1) BuildRequires: it is gone since
  version 3.3.2.
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GnomeBluetooth-1_0
  subpackage.
- Add typelib-1_0-GnomeBluetooth-1_0 Requires to devel subpackage.
* Sat Nov 26 2011 dimstar@opensuse.org
- Remove all .la files: gnome-bluetooth-applet.la on its own has
  reference to the other la files, so keeping some of them breaks
  more than it serves.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Library:
  - Clean up public API
  - Port to GDBus
  - Small UI fixes to the chooser
  + Properties:
  - Move to gnome-control-center
  + Wizard:
  - Remove special-case Wiimote handling (now in Bluez)
  - Remove multi-adapter support
  + Updated translations.
- Drop gnome-bluetooth-fix-crash.patch: fixed upstream another way.
- Rename libgnome-bluetooth8 to libgnome-bluetooth9, following
  soversion bump.
* Mon Oct 17 2011 dimstar@opensuse.org
- Update to version 3.2.1:
  + Fix warnings about BluetoothStatusClass
  + Fix small memory leaks
  + Updated translations.
* Tue Oct 11 2011 vuntz@opensuse.org
- Add gnome-bluetooth-fix-crash.patch: fix various crashes in
  libgnome-bluetooth, that help a bit getting bluetooth working in
  GNOME. Part of bnc#722722.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Sep 21 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Properties:
  - Use links to link to other panels
  - Fix rounded toolbar buttons
  + Applet:
  - Fix "browse" menu item
  + Updated translations.
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 3.1.4:
  + Properties: Fix crash when device has no UUIDs
  + Applet: Change preferences menu items to match the gnome-shell
    UI
  + Updated translations.
- Drop gnome-bluetooth-libgnome-control-center.patch: fixed
  upstream.
- Remove now unneeded gnome-common BuildRequires and call to
  gnome-autogen.sh.
* Wed Aug  3 2011 vuntz@opensuse.org
- Add gnome-bluetooth-libgnome-control-center.patch: the new
  gnome-control-center doesn't install libgnome-control-center
  development files, so work around this.
- Add gnome-common BuildRequires and call to gnome-autogen.sh,
  needed for the patch.
- Remove now unneeded pkgconfig(libgnome-control-center)
  BuildRequires.
* Mon Jul  4 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Properties:
  - Show extra configuration widgets in the properties
  - Add Send/Browse buttons
  - Small UI changes
  + Applet:
  - Fix crasher when "Browsing device" using the menu item
  - Fix "Send To..." overquoting the Bluetooth address
  + Wizard:
  - Handle Wiimote pairing through newer bluez
  - Fix a lot of keys not working in the custom PIN entry
  - Fix display of Secure Simple Pairing passkeys
  - Add old Apple wireless mouse to the PIN database
* Fri May 27 2011 vuntz@opensuse.org
- Update to version 3.0.1:
  + Applet:
  - Fix crasher when using "browse"
  - Fix startup not working in fallback mode
  + Wizard:
  - Add support for more Wiimotes
  - Fix custom PIN entry not working as expected
  - Fix display of SSP passkeys
  + Library:
  - Fix possible warnings in debug mode
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Properties:
  - Show link to touchpad settings for touchpads
  - Hide labels when no devices are selected
  + Updated translations.
* Tue Mar 29 2011 fcrozat@novell.com
- Update to version 2.91.92:
  + Properties:
  - Use dim labels
  - Fix translation problems
  - Use the inline-toolbar style
  + Geoclue plugin:
  - Use GSettings instead of GConf
  + Wizard:
  - Add Magic Trackpad quirk
- Update to version 2.91.91:
  + Properties:
  - Put in the control-center's Hardware category
  - Redesign for GNOME 3
  + Applet:
  - Only start the applet in the fallback session
  + Library:
  - Fix a possible warning in the button chooser
  + Sendto:
  - Re-enable sento plugin for GNOME 3.0
  - Make double-click select a device
  - Add desktop file for nice name in the shell
  - Fix packing in dialogue
  + Wizard:
  - Add desktop file for nice name in the shell
- Changes fromv version 2.91.5:
  + Properties:
  - Make dialogue parenting work for errors
  + Library:
  - Use BluetoothClient to track default adapter
  - Don't free request_key and passkey in agent reply functions.
  - Set log domain to differentiate library messages from the
    lib's ones
  + Applet:
  - Fix crash in bluetooth_applet_create_device_from_iter()
  - Fix crash when creating an agent
  - Fix crash when unref'ing a DBusGMethodInvocation
  - Fix crash when there's no default adapter
  + Moblin:
  - Fix compilation of the Moblin front-end
- Changes from version 2.91.2:
  + Update command to launch Bluetooth panel
  + Fix i18n in the panel
  + Make test-plugins test command more useful
  + Fix adapter not going powered when coming back from hard-block
  + Allow setup of devices that don't support pairing
  + Make sure the icon is shown/hidden when killswitch state
    changes.
  + Make sure all the unblocked adapters get powered on startup
  + Fix visible menu item disappearing after suspend
  + Make --dump-devices work again in the applet, and
    fix its output for some services
  + Refactor applet as a library, for use in gnome-shell
  + Build fixes
- Changes from version 2.90.0:
  + Port to GSettings, GTK+ 3.x and GtkApplication
  + Use GBinding instead of copy/paste Seahorse code
  + Plenty of killswitch bug fixes
  + Applet:
  - Fix browsing a device when already mounted
  - Use symbolic icons
  + Properties:
  - Port to gnome-control-center 3.x API
  - Add a specific page when Bluetooth is hard-blocked
  + Moblin/MeeGo:
  - Use bluetoothd backed power switch
  - Some re-designs for meego
- Change obexed Requires to obexd-client.
- Drop gnome-bluetooth-fix-introspection-build.patch: fixed
  upstream.
- Remove no longer needed libunique-devel BuildRequires.
- Add pkgconfig() BuildRequires now needed: dbus-glib-1, gtk+-3.0,
  libgnome-control-center.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: nautilus-sendto-devel
  + New ones: nautilus-sendto.
- Add support for source service checkout, with %%BUILD_FROM_VCS:
  + Add gnome-common and gtk-doc BuildRequires.
  + Add call to ./autogen.sh.
  + Enforce gtk-doc html generation by passing --enable-gtk-doc to
    configure.
* Fri Feb 18 2011 fcrozat@novell.com
- Add 61-gnome-bluetooth-rfkill.rules: add ACL to rfkill device.
  This will be replaced by urfkill in the future, but in the
  meantime, people need to be able to switch off devices. Fix
  bnc#632256.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Oct  1 2010 vuntz@opensuse.org
- Add gnome-bluetooth-fix-introspection-build.patch, which
  obsoletes gnome-bluetooth-fix-parallel-build.patch: this updated
  patch will really fix the build with recent
  gobject-introspection.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Sat Sep 18 2010 vuntz@opensuse.org
- Remove gir-repository BuildRequires: this was only needed for the
  DBusGLib gir, which is now part of gobject-introspection.
- Add gnome-bluetooth-fix-parallel-build.patch: this updates the
  build system for introspection, to work correctly. This requires
  the gnome-common BuildRequires and the call to gnome-autogen.sh.
* Mon Sep 13 2010 vuntz@opensuse.org
- Update to version 2.31.90:
  + More killswitch fixes
  + Fix crasher when Bluetooth nautilus-sendto plugin is loaded
* Mon Sep  6 2010 vuntz@opensuse.org
- Do not add a GenericName to bluetooth-applet.desktop: it's an
  autostart file, so it's not needed.
- Do not add/change GenericName and Name for
  bluetooth-properties.desktop: it only appears in the control
  center now, and we don't need to change those keys in this case
  (the changes made sense for the applications menu).
* Fri Aug 27 2010 vuntz@opensuse.org
- Add Supplements to automatically install plugins-geoclue if
  gnome-bluetooth and geoclue are installed.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + Allow setting up devices that do not use pairing
  + Port to GSettings instead of GConf
  + Properties:
  - Add specific page when the only adapter is hard blocked
    through a physical killswitch
- Remove --disable-schemas-install from configure call
  (gconf-specific) and update packaging to handle GSettings schemas
  instead of gconf schemas.
- Rename libgnome-bluetooth7 to libgnome-bluetooth8 after bump in
  library soname.
* Tue Aug  3 2010 dimstar@opensuse.org
- Require bluez and obexd, fixes bnc#622946.
* Mon Jun 21 2010 vuntz@opensuse.org
- Revert previous change about adding HardwareSettings category to
  bluetooth-properties.desktop, post-11.3.
* Mon Jun 21 2010 vuntz@opensuse.org
- Add HardwareSettings category to bluetooth-properties.desktop to
  make it appear at the right place. This is needed because
  update-desktop-files won't keep the X-GNOME-* categories in 11.3.
* Fri Jun  4 2010 vuntz@opensuse.org
- Fix calls to suse_update_desktop_file: the arguments were not in
  the right order.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Add PIN code for Navman GPS
  + Updated translations.
* Mon Feb 15 2010 dimstar@opensuse.org
- Update to version 2.29.91:
  + Mention gnome-user-share in the documentation
  + Applet:
  - Link to the sound preferences for audio devices
  - Remove hard-coded use of nautilus
  + Library:
  - Use spinner from GTK+
  - Install introspection data properly
  - API documentation fixes
  - Fix some parts of the UI not being translated at run-time
  + Wizard:
  - Fix run-time warning when pairing a new device
  + Moblin applet;
  - Add summary page support
  - Fix a number of memory leaks and possible crashers
  + Sendto:
  - Fix crash when obex-client isn't already running
  - Make Cancel button actually work
  - Implement "retry" when sending fails
  - Fix progress bar when sending multiple files
- Drop upstream merged gnome-bluetooth-introspection-install.patch.
* Thu Dec 10 2009 aj@suse.de
- Remove unused BuildRequires hal-devel
* Thu Dec  3 2009 vuntz@opensuse.org
- Update to version 2.29.3:
  + Build and install nautilus-sendto plugin by default
  + Preferences:
  - Add a button to access "Personal File Sharing" preferences
  + Library:
  - Clean up combo box selection widget
  - Make it possible to set the selected device in the chooser
  - Make the button chooser select the device when popping up a
    dialogue
  + Sendto:
  - Wrap errors instead of clipping them
  + Wizard:
  - Make it possible to re-pair devices
- Changes from version 2.29.2:
  + Add Moblin front-end for gnome-bluetooth
  + Add experimental nautilus-sendto plugin
  + Applet:
  - Fix applet showing the wrong connection information
  - Use separate icon for the status icon, for monochromatic
    themes
  - Add discoverable menu item
  - Fix a number of rfkill related bugs
  + Library:
  - Make it possible use another widget for device filtering
  - Don't overwrite UUIDs when discovering known devices
  - Add BluetoothChooserCombo widget
  - Fix usage under non-UTF-8 locales
- Add nautilus-sendto-devel BuildRequires and create
  nautilus-sendto-plugin-bluetooth subpackage.
- Enable introspection: add gir-repository and
  gobject-introspection-devel BuildRequires, pass
  - -enable-introspection to configure.
- Add gnome-bluetooth-introspection-install.patch to fix
  installation of introspection data.
* Sat Oct 24 2009 andrea@opensuse.org
- added LXDE support to /etc/xdg/autostart/bluetooth-applet.desktop
* Tue Sep 29 2009 vuntz@opensuse.org
- Update to version 2.28.1:
  + Applet:
  - Fix most devices showing up as connected when they aren't
  - Make sure the pairing agent is only bound to the default
    adapter
  + All:
  - String fixes
  - API documentation updates
  - Filtering fixes in the BluetoothChooser
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Applet:
  - Applet fails to connect to disconnected audio devices
  - Fix crash when getting a pairing request from a known rfcomm
    device
  + Wizard:
  - Fix pairing of devices that require a PIN entry
* Thu Sep  3 2009 dimstar@opensuse.org
- Update to version 2.27.90:
  + Fix crasher when exiting and the NetworkManager plugin was
    installed.
  + Fix wizard not loading because of a bug in the UI definition.
  + Fix keyboard not working.
* Wed Aug  5 2009 dominique-obs@leuenberger.net
- Update to version 2.27.9:
  + All:
  - Port to using new rfkill API in Linux kernel 2.6.31
  + Applet:
  - Hide unwanted menu items when Bluetooth isn't available
  - Fix connecting to Sony Ericsson phones
  - Fix a crash when disconnecting an audio device
  - Fix devices showing up as connected when they were not
  + Properties:
  - Close the preferences dialogue when pressing 'Esc'
  + Wizard:
  - Mention "enter" when pairing a keyboard
  - String fixes
  + Library:
  - Track whether devices are connecting, as opposed to already
    connected
* Fri Jul 31 2009 vuntz@novell.com
- Remove Obsoletes for libgnome-bluetooth2 and libgnome-bluetooth6.
* Wed Jul 29 2009 dominique-obs@leuenberger.net
- Update to version 2.27.8:
  + All:
  - A number of UI strings changes
  + Applet:
  - Make "Connect" in the menu for devices appear correctly after
    pairing
  - Filter for paired ObexFTP devices in the browse menu item
  + Preferences:
  - Add link to help
  + Wizard:
  - Fix crash when selecting a device where the name hasn't been
    resolved yet
  + Library:
  - Add introspection support
  - Export device and adapter models for easy enumeration
  - Fix broken filtering for device category
  - Fix possible crasher in spinner widget
  - Ellipsise names in the chooser widget
  - A number of API documentation fixes
- Rename libgnome-bluetooth6 to libgnome-bluetooth7 because of
  soname change.
- Have libgnome-bluetooth7 Obsoletes libgnome-bluetooth6.
* Sat Jun 27 2009 captain.magnus@opensuse.org
- Update to version 2.27.7.1:
  + When deleting a device, pass it through the plugins
    to delete any other associations
  + Add a test program
  + Add Geoclue GPS setup plugin
  + Fix pairing some fixed PIN devices, and misc fixes
- Create subpackage plugins-geoclue
* Wed Jun 17 2009 vuntz@novell.com
- Update to version 2.27.6:
  + Applet:
  - Use a better tooltip for the applet
  - Add "Send File" and "Browse files" menu item for devices that
    support it
  - Add menu items to call the preferences for mice and keyboards
  - Fix assertions when removing a device, and pairing it again
    without the applet being restarted
  - Don't show "Connect" for devices without input or audio
    capabilities
  - Support notification-daemon without any support for actions,
    as used in Ubuntu
  - Pass the device name to bluetooth-sendto
  - Rework UI of all the pairing helper dialogues
  + Preferences:
  - Fix the adapter page not showing up when restarting
    bluetoothd
  - Add --dump debug option, to dump a list of all known devices
    and their properties
  + Send-to:
  - Fix warning when sending an empty file
  - Remove use of red labels on errors
  - Remove obex-data-server support, and require obexd
  - Try harder to get a device name
  + Wizard:
  - Fix handling for devices that use random passkeys, but can't
    handle 6 digits (such as Sony CMT-DH5BT)
  - Add Simple Pairing support
  - Try harder to connect to devices after pairing them, fixes
    the Microsoft Wireless Notebook Presenter Mouse 8000 not
    working straight after pairing
  - Allow skipping name resolution when we would be using a fixed
    passkey
  - Don't allow stepping back in the middle of pairing
  - Add more instructions on the front page
  - Many many UI changes
  + Library:
  - Allow getting arbitrary data from the backend for
    BluetoothChooser users
  - Only export the supported symbols in the library
  - Add plugin support, so third-party applications can be setup,
    for a particular device, from the preferences or the wizard
  - Replace the search button with a "Searching" label and spinner
- Rename libgnome-bluetooth2 to libgnome-bluetooth6, and have it
  Obsoletes libgnome-bluetooth2 <= 2.27.5.
* Thu May  7 2009 vuntz@novell.com
- Update to version 2.27.5:
  + Fix some killswitch related bugs
  + Work with older versions of Pango
  + Fix pairing with Blackberry and Samsung phones
  + Use the services status to check the connection status, makes
    connecting/disconnecting devices much faster
  + Add a quit menu to the applet, when in debug mode
  + Fix passkey special-casing when a OUI is used
* Sun May  3 2009 mboman@suse.de
- Change BuildRequires from unique-devel to libunique-devel
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.27.4:
  + Fix display of labels on the passkey page, and of the passkey
    on the passkey options dialogue
  + More use of GtkBuilder in the wizard
  + First pass at user-targetted documentation
  + Fix a few memory leaks
  + Fix crash when running properties installed
- Changes from version 2.27.3:
  + Fix schema installation
  + Make sure the applet works even without the schema being
    installed properly
  + Fix display of devices with underscores in their name in the
    applet
  + Fix some devices with no real audio support (AVCRP phones for
    example) showing up in the applet
- Add gnome-doc-utils-devel BuildRequires.
- Pass --disable-scrollkeeper to configure.
- Package documentation too.
- Use fdupes.
* Wed Apr  8 2009 vuntz@novell.com
- Update to version 2.27.2:
  + General:
  - Use our own "paired" icon, to avoid confusion in some themes
  - Remove "Trust" from the UI, it's an implementation detail
  - Group input and audio device-types under the same heading in
    the chooser
  + Applet:
  - Use new "disabled" icons
  - Add a status label for the killswitch menu item
  - Add the ability to connect/disconnect from devices directly
    from the applet's menu
  + Properties:
  - Only show the default adapter, and simplify the UI
  - Show a way to turn off the killswitch when there's no
    Bluetooth adapters in the machine
  + Wizard:
  - Don't show "Enter passkey" when we know the passkey of the
    device already
  - Remove special-casing of mice, and PS3 BD remote from the
    code and into the database
  - Move passkey options button back into the content area, from
    the action area
  - Simplify passkey options dialogue
  - Connect to input and audio devices when setup finishes
  - Mark all the newly paired devices as trusted
  - Fix the wizard not allowing to get past the search page when
    the device selected didn't have a name at first
  - Port quirks database to XML
  - Add quirk for the Bluemax Bluetooth GPS Receiver GPS-009
  - Add quirk for the Nintendo Wiimote
  - Add quirk for iBT-GPS, and another GPS
  + Sendto:
  - Fix obex-data-server support
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Mar 15 2009 vuntz@novell.com
- Add Obsoletes/Provides for libgnomebt-devel.
- Make gnome-bluetooth Obsoletes/Provides bluez-gnome since it's a
  drop-in replacement for bluez-gnome.
- Don't set the name in bluetooth-applet.desktop to the preexisting
  value.
* Fri Mar  6 2009 mboman@suse.de
- Update to version 2.27.1:
  + This is basically a new package, forked from bluez-gnome
* Sun Feb 22 2009 vuntz@novell.com
- Update to version 0.12.0:
  + Remove gnome-obex-server, as it's replaced by gnome-user-share
- Drop BuildRequires: perl-XML-Parser, update-desktop-files
- Drop Requires: gnome-vfs2
- soname changed, so rename libgnometbt0 to libgnomebt1. No
  Provides/Obsoletes since it's not the case.
- Remove gnome-bluetooth package since it only contains data that
  should be in libgnomebt1 now. Have libgnomebt1 Obsolete/Provide
  it.
* Fri Mar 21 2008 jpr@suse.de
- Remove incorrect libgnomebt-devel requires
- Remove .la files
* Fri Feb  1 2008 rodrigo@suse.de
- Update to version 0.11.0:
  * Remove gnome-obex-send as it's replaced by bluez-gnome's
    bluetooth-sendto
* Tue Oct 30 2007 coolo@suse.de
- also obsolete 0.8.0
* Thu Oct 25 2007 jpr@suse.de
- Update to 0.9.1
  * Fix a typo that meant the obex server was crashing when receiving
  a file
  * Send a disconnect when we finish sending a file, fixes reception
  of files on some devices
  * Use new GTK+ features for the tray icon
  * Build fixes
- Remove gnome-bluetooth-desktop.diff and use
  %%suse_update_desktop_file instead
- Remove gnome-bluetooth-pixmapsdir.patch, the icon hierarchy is used
  now
- Remove gnome-bluetooth-transparent-trayicon.patch and
  dont-disable-deprecated, libegg is no  longer used
- Remove gnome-bluetooth-fail-cleanly.patch, the UI it changed is
- Split off libgnomebt0, python-gnome-bluetooth and
  gnome-bluetooth-lang
- Rename gnome-bluetooth-devel to libgnomebt-devel
* Wed Aug  8 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage
- s#%%run_ldconfig#/sbin/ldconfig/ in %%post and %%postun.
* Fri Jul 27 2007 maw@suse.de
- Add dont-disable-deprecated.patch.
* Wed May 23 2007 prusnak@suse.cz
- added libusb-devel to BuildRequires
- added libopenssl-devel to Requires of devel subpackage
* Fri May 18 2007 prusnak@suse.cz
- removed X-SuSE-translate from desktop file
* Thu May  3 2007 prusnak@suse.cz
- changed expat to libexpat-devel in Requires of devel subpackage
* Sun Feb 18 2007 aj@suse.de
- Cleanup BuildRequires.
* Thu Jan 18 2007 jhargadon@suse.de
- removed useless .la files (#223699)
* Tue Dec 19 2006 sbrabec@suse.cz
- Spec file cleanup.
* Mon Dec 18 2006 maw@suse.de
- Move to /usr.
* Thu Nov 30 2006 sbrabec@suse.cz
- Fixed devel dependencies.
* Tue Sep 19 2006 jhargadon@suse.de
- update to version 0.8.0
- Fix icons not showing up properly
- Allow passing URIs as well as local filenames to gnome-obex-send
- Save to ~/Desktop/Downloads by default, then fallback to ~/Desktop and ~/,
  as Epiphany does, or to the user specified directory
- Remove direct openobex and bluez-devel dependencies, as well as gnome-vfs
- Remove the useless gnome-bluetooth-manager
- translation updates
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Wed Aug 16 2006 ro@suse.de
- added python-gobject2-devel to BuildRequires
* Mon Mar 20 2006 danw@suse.de
- Fail cleanly (with a dialog rather than a message to stderr) if
  bluetooth is not configured on the machine. #140780
* Fri Mar 10 2006 danw@suse.de
- Make the gnome-obex-server trayicon transparent. #155345
* Sat Feb 18 2006 stbinner@suse.de
- move GenericName entries in .desktop files to Comment
* Mon Feb  6 2006 hpj@suse.de
- Added Rodney's pixmap path patch.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 29 2005 sbrabec@suse.cz
- Updated to version 0.7.0.
* Wed Nov  9 2005 sbrabec@suse.cz
- Fixed more random return values.
- Removed .mo install hack, locales now install properly.
* Thu Nov  3 2005 sbrabec@suse.cz
- Updated to version 0.6.0.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed May  4 2005 sbrabec@suse.cz
- Fixed some GCC 4 warnings.
* Wed Apr 27 2005 sbrabec@suse.cz
- Added gnome hbox patch from Harald Hoyer <harald@redhat.com>
  (#72172).
- Added patch for crash on file send.
  http://bugzilla.gnome.org/show_bug.cgi?id=150388
* Wed Nov 24 2004 ro@suse.de
- fix build with new python2.4
* Tue Nov 23 2004 hvogel@suse.de
- correct desktop files
- include icon
- fix ac-quotation
* Wed Sep  8 2004 ro@suse.de
- require python-gnome instead of gnome-python
* Fri Sep  3 2004 hhetter@suse.de
- use lib64 on 64bit systems in PYTHONPATH
* Thu Sep  2 2004 hhetter@suse.de
- part of Bug #44638, require gnome-python, fix PYTHONPATH
  in gnome-bluetooth-manager
* Mon Aug  2 2004 ro@suse.de
- update to 0.5.1 to make it build again with current environment
* Thu Jan 29 2004 hhetter@suse.de
- initial SUSE package
